@@ -1,7 +1,12 @@
 print.ccPower <-
 function(x,...,digits=-1){
   cat("Number of simulations, B: ",x$B,"\n")
-  cat("Sample size at phase I:",sum(x$N),"\n")
+  if(is.null(x$NI[1])){
+    cat("Sample size at Phase I:",sum(x$N),"\n")
+  }else{
+    cat("Sample size at Phase I for controls:",x$NI[1],"\n")
+    cat("Sample size at Phase I for casess:",x$NI[2],"\n")
+  }
   cat("'True' regession coefficients, betaTruth:",x$beta,"\n")
   cat("\n")
   if(digits==-1){
